# matmalib

## About
This is a Python package designed by the Marianski Lab to easily create and design figures for publication, do data analysis from reading the output files of several commonly used QChem software such as Gaussian 16, ORCA, CP2k FHI-AIMS, and GROMMACS, create input files for these pieces of ssoftware and help automate several different computational chemistry workflows.

Documentation for the colors can be found [here](https://pratiman-91.github.io/colormaps/docs/Sequential)

## Dependencies
You need the following python packages to use this package:  

Python >= 3.12  

Numpy  
Matplotlib  
Colormap <br>
Networkx <br>
py3Dmol <br>

In your conda environment, run: <br>
```
conda install numpy matplotlib colormap networkx py3Dmol
```

## Install Instructions
To install the package you can run  
```
pip install matmalib
```

To update the package:
```
pip install matmalib --upgrade
```
